@@ -6,6 +6,7 @@ use AsyncAws\Core\AbstractApi;
 use AsyncAws\Core\AwsError\AwsErrorFactoryInterface;
 use AsyncAws\Core\AwsError\JsonRpcAwsErrorFactory;
 use AsyncAws\Core\Configuration;
+use AsyncAws\Core\Exception\UnsupportedRegion;
 use AsyncAws\Core\RequestContext;
 use AsyncAws\Core\Result;
 use AsyncAws\Sqs\Enum\MessageSystemAttributeName;
@@ -890,6 +891,44 @@ class SqsClient extends AbstractApi
         }
 
         switch ($region) {
+            case 'af-south-1':
+            case 'ap-east-1':
+            case 'ap-northeast-1':
+            case 'ap-northeast-2':
+            case 'ap-northeast-3':
+            case 'ap-south-1':
+            case 'ap-south-2':
+            case 'ap-southeast-1':
+            case 'ap-southeast-2':
+            case 'ap-southeast-3':
+            case 'ap-southeast-4':
+            case 'ap-southeast-5':
+            case 'ap-southeast-7':
+            case 'ca-central-1':
+            case 'ca-west-1':
+            case 'eu-central-1':
+            case 'eu-central-2':
+            case 'eu-north-1':
+            case 'eu-south-1':
+            case 'eu-south-2':
+            case 'eu-west-1':
+            case 'eu-west-2':
+            case 'eu-west-3':
+            case 'il-central-1':
+            case 'me-central-1':
+            case 'me-south-1':
+            case 'mx-central-1':
+            case 'sa-east-1':
+            case 'us-east-1':
+            case 'us-east-2':
+            case 'us-west-1':
+            case 'us-west-2':
+                return [
+                    'endpoint' => "https://sqs.$region.amazonaws.com",
+                    'signRegion' => $region,
+                    'signService' => 'sqs',
+                    'signVersions' => ['v4'],
+                ];
             case 'cn-north-1':
             case 'cn-northwest-1':
                 return [
@@ -940,22 +979,39 @@ class SqsClient extends AbstractApi
                     'signService' => 'sqs',
                     'signVersions' => ['v4'],
                 ];
+            case 'fips-us-gov-east-1':
+            case 'us-gov-east-1':
+                return [
+                    'endpoint' => 'https://sqs.us-gov-east-1.amazonaws.com',
+                    'signRegion' => 'us-gov-east-1',
+                    'signService' => 'sqs',
+                    'signVersions' => ['v4'],
+                ];
+            case 'fips-us-gov-west-1':
+            case 'us-gov-west-1':
+                return [
+                    'endpoint' => 'https://sqs.us-gov-west-1.amazonaws.com',
+                    'signRegion' => 'us-gov-west-1',
+                    'signService' => 'sqs',
+                    'signVersions' => ['v4'],
+                ];
+            case 'fips-us-iso-east-1':
             case 'us-iso-east-1':
+                return [
+                    'endpoint' => 'https://sqs.us-iso-east-1.c2s.ic.gov',
+                    'signRegion' => 'us-iso-east-1',
+                    'signService' => 'sqs',
+                    'signVersions' => ['v4'],
+                ];
+            case 'fips-us-iso-west-1':
             case 'us-iso-west-1':
                 return [
-                    'endpoint' => "https://sqs.$region.c2s.ic.gov",
-                    'signRegion' => $region,
-                    'signService' => 'sqs',
-                    'signVersions' => ['v4'],
-                ];
-            case 'us-isof-east-1':
-            case 'us-isof-south-1':
-                return [
-                    'endpoint' => "https://sqs.$region.csp.hci.ic.gov",
-                    'signRegion' => $region,
+                    'endpoint' => 'https://sqs.us-iso-west-1.c2s.ic.gov',
+                    'signRegion' => 'us-iso-west-1',
                     'signService' => 'sqs',
                     'signVersions' => ['v4'],
                 ];
+            case 'fips-us-isob-east-1':
             case 'us-isob-east-1':
                 return [
                     'endpoint' => 'https://sqs.us-isob-east-1.sc2s.sgov.gov',
@@ -963,14 +1019,25 @@ class SqsClient extends AbstractApi
                     'signService' => 'sqs',
                     'signVersions' => ['v4'],
                 ];
+            case 'fips-us-isof-east-1':
+            case 'us-isof-east-1':
+                return [
+                    'endpoint' => 'https://sqs.us-isof-east-1.csp.hci.ic.gov',
+                    'signRegion' => 'us-isof-east-1',
+                    'signService' => 'sqs',
+                    'signVersions' => ['v4'],
+                ];
+            case 'fips-us-isof-south-1':
+            case 'us-isof-south-1':
+                return [
+                    'endpoint' => 'https://sqs.us-isof-south-1.csp.hci.ic.gov',
+                    'signRegion' => 'us-isof-south-1',
+                    'signService' => 'sqs',
+                    'signVersions' => ['v4'],
+                ];
         }
 
-        return [
-            'endpoint' => "https://sqs.$region.amazonaws.com",
-            'signRegion' => $region,
-            'signService' => 'sqs',
-            'signVersions' => ['v4'],
-        ];
+        throw new UnsupportedRegion(\sprintf('The region "%s" is not supported by "Sqs".', $region));
     }
 
     protected function getServiceCode(): string
