@@ -2,6 +2,8 @@
 
 namespace AsyncAws\Sqs\ValueObject;
 
+use AsyncAws\Core\Exception\InvalidArgument;
+
 /**
  * Encloses the `Id` of an entry in `ChangeMessageVisibilityBatch.`.
  */
@@ -9,6 +11,8 @@ final class ChangeMessageVisibilityBatchResultEntry
 {
     /**
      * Represents a message whose visibility timeout has been changed successfully.
+     *
+     * @var string
      */
     private $id;
 
@@ -19,9 +23,14 @@ final class ChangeMessageVisibilityBatchResultEntry
      */
     public function __construct(array $input)
     {
-        $this->id = $input['Id'] ?? null;
+        $this->id = $input['Id'] ?? $this->throwException(new InvalidArgument('Missing required field "Id".'));
     }
 
+    /**
+     * @param array{
+     *   Id: string,
+     * }|ChangeMessageVisibilityBatchResultEntry $input
+     */
     public static function create($input): self
     {
         return $input instanceof self ? $input : new self($input);
@@ -31,4 +40,12 @@ final class ChangeMessageVisibilityBatchResultEntry
     {
         return $this->id;
     }
+
+    /**
+     * @return never
+     */
+    private function throwException(\Throwable $exception)
+    {
+        throw $exception;
+    }
 }
